import os
import xarray as xr


def AddEnsCoord(BaseDir, EnsType):
    fs = []
    for i in range(1, 41):
        filename = os.path.join(BaseDir, f'output_{EnsType}_{i}/output.nc')
        f = xr.open_dataset(filename)
        f = f.drop_vars(['f_atm_x', 'f_atm_y', 'f_wat_x', 'f_wat_y', 'f_stress_x', 'f_stress_y'])
        f = f.assign_coords({'ens': (['ens',], [i], {'long_name': 'ensemble index', 'standard_name': 'ensemble number', 'units': '1'})})
        fs.append(f)
    return xr.combine_by_coords(fs)


def DropDim(f, dims):
    for dim in dims:
        try:
            f['Mesh2'] = f['Mesh2'][{dim: 0}].drop(dim)
            f['Mesh2_node_x'] = f['Mesh2_node_x'][{dim: 0}].drop(dim)
            f['Mesh2_node_y'] = f['Mesh2_node_y'][{dim: 0}].drop(dim)
            f['Mesh2_face_nodes'] = f['Mesh2_face_nodes'][{dim: 0}].drop(dim)
        except KeyError:
            pass
    return f


def MergeEnsData(BaseDir, EnsType):
    return DropDim(AddEnsCoord(BaseDir, EnsType), ['ens', ])


def MergeTimeData(files, time_slices):
    f = files[0]
    time_slices = [(i, j) if j > 0 else (i, f.dims['time'] + j) for f, (i, j) in zip(files, time_slices)]
    files[0] = f.isel(time=range(*time_slices[0]))
    files[1:] = [f.isel(time=range(i, j)) for f, (i, j) in zip(files[1:], time_slices[1:])]
    print(files[0].time[-1].data, files[1].time[0].data)
    return xr.merge(files)


if __name__ == '__main__':
    MergeEnsData('.', 'analysis').to_netcdf('output_analysis.nc')
    MergeEnsData('.', 'ensemble').to_netcdf('output_ensemble.nc')