import xarray as xr
import numpy as np

import obs as O
import model as M


def getGeometry(f):
    x = f['Mesh2_node_x']
    y = f['Mesh2_node_y']
    triangles = f['Mesh2_face_nodes']
    return x, y, triangles


def genObs():
    f = xr.open_dataset('truth.nc', decode_times=False)
    x, y, triangles = getGeometry(f)
    model = M.MEB(x.to_numpy(), y.to_numpy(), triangles.to_numpy())


    grids = {'area': 'fulldomain', 
             'thickness': 'alongtrack',
             'u': 'sparse', 'v': 'sparse'}

    obs = O.Observation(model, grids)
    nobs = obs.ObsDim
    print (obs.dim)
    y = np.zeros(nobs)
    sig_obs = np.zeros(nobs)

    Ntsu = int(f['time'][1008])//30
    nt = 720*4*30 + 1
    Sc = 720*4

    for it in range(nt):
        if it % Sc == 0:
            print (f['time'][1008 + it//120].to_numpy()/30)
            yt = obs.H(model.getStateVector(f.isel(time=1008 + it//120), True), model)
            obs.genSynthetic(it + Ntsu, yt, y, sig_obs)


if __name__ == '__main__':
    genObs()
