#!/usr/bin/env python

import numpy as np

varnames = ('area', 'cohesion', 'thickness', 'damage', 'u', 'v',
            'stress_xx', 'stress_xy', 'stress_yy', )
global_params = ( )

varnames_state = ('area', 'cohesion', 'thickness', 'damage', 'u', 'v',
            'stress_xx', 'stress_xy', 'stress_yy', )

global_params_state = ( )


class MEB:
    def __init__(self, x, y, triangles):
        """initialise the model
        """

        self.dim = dict()
        cumsum = 0
        for varname in varnames_state:
            start = cumsum
            cumsum += self.len(varname)
            self.dim[varname] = (start, cumsum)

        for varname in global_params_state:
            start = cumsum
            cumsum += 1
            self.dim[varname] = (start, cumsum)

        self.total = cumsum
        self.x_c = x[triangles].mean(axis=1)
        self.y_c = y[triangles].mean(axis=1)
        self.x = x
        self.y = y

    def coord(self, varname):
        if (varname == 'u') or (varname == 'v'):
            return self.x, self.y
        else:
            return self.x_c, self.y_c
        


    def getStateVector(self, f, is_truth):
        """get updated model field into state vector"""
        if is_truth:
            E = np.zeros(self.total)
        else:
            E = np.zeros((40, self.total))

        for varname in varnames_state:
            E[..., range(*self.dim[varname])] = f[varname]

        return E


    def getField(self, varname, state):
        return state[range(*self.dim[varname])]

    def len(self, varname):
        length = {'u':285, 'v':285, 'area':512, 
                  'cohesion':512, 'thickness':512,
                  'damage':512, 'stress_xx':512,
                  'stress_yy':512, 'stress_xy':512}
        return length[varname]

