#!/usr/bin/env python
# -*- coding: iso-8859-15 -*-h


############################################################
#
#      (c)   Marc Bocquet, ENPC/CEREA
#      Programme ienks.py
#      Initial release: 22 June 2015
#      Latest modification: 21 Feb 2022 by Yumeng Chen
#
############################################################

import os
import shutil

from ienks_call import ienks_call
import parallel
import MEB_online as model
from concat_analysis import MergeEnsData

para = parallel.parallelization(n_model_PE=1)

######################
#  Global Variables  #
######################

# Length of the data assimilation run
Nt = 720*4*30 + 1

# Ensemble size
N =  40
assert para.size_world//para.n_model_PE == N, 'number of CPUs is not correct'

# Lenght of the data assimilation window
L = 0

# Shift between updates (in unit of Dt)
S = 720*4 # 1day

# Inflation factor
infl = 1.02

os.makedirs('obs', exist_ok=True)

gridtypes = ({'area': 'fulldomain',}, 
             {'area': 'fulldomain','thickness': 'alongtrack', }, 
             {'area': 'fulldomain','u': 'sparse','v': 'sparse',},
             { 'thickness': 'alongtrack', 'u': 'sparse', 'v': 'sparse',},
             {'area': 'fulldomain', 'thickness': 'alongtrack', 'u': 'sparse', 'v': 'sparse',},
             )
obsname = {'area':'A', 'thickness':'H', 'u':'U', 'v':'V'}
model.argv[4] = f'--input.restartfile-timeindex={0}'

L_radius = [{'area':5, 'thickness':30, 'u':30, 'v':30}, ]
##########################
#  Data assimilation run  #
###########################
if para.PE['filter']:
    print("> run")

for gridtype in gridtypes:
    for dl_radius in L_radius:
        ienks_call(para, Nt, N, L, S, infl, dl_radius, gridtype, doN=False)
        para.comm_world.Barrier()
        if para.PE['filter']:
            MergeEnsData('.', 'analysis').to_netcdf('output_analysis.nc')
            MergeEnsData('.', 'ensemble').to_netcdf('output_ensemble.nc')
            dirname='results_'+''.join([f'{obsname[key]}' for key in gridtype])
            os.makedirs(dirname, exist_ok=True)
            # shutil.move('output_truth_0/output.nc', f'{dirname}/truth.nc')
            ierr = os.system('rm -rf output_*/')
            shutil.move('output_analysis.nc', f'{dirname}/output_analysis.nc')
            shutil.move('output_ensemble.nc', f'{dirname}/output_ensemble.nc')
            ierr = os.system(f'mv param_*.npz {dirname}/')
        para.comm_world.Barrier()
