import numpy as np
from MEB_online import varnames_state
import pyMEB


def GC(dists, radius):
    coeffs = np.zeros(dists.shape)
    R = radius * 1.82  # =np.sqrt(10/3). Sakov: 1.7386
    # 1st segment
    ind1         = dists <= R
    r2           = (dists[ind1] / R) ** 2
    r3           = (dists[ind1] / R) ** 3
    coeffs[ind1] = 1 + r2 * (- r3 / 4 + r2 / 2) + r3 * (5 / 8) - r2 * (5 / 3)
    # 2nd segment
    ind2         = np.logical_and(R < dists, dists <= 2*R)
    r1           = (dists[ind2] / R)
    r2           = (dists[ind2] / R) ** 2
    r3           = (dists[ind2] / R) ** 3
    coeffs[ind2] = r2 * (r3 / 12 - r2 / 2) + r3 * (5 / 8) \
        + r2 * (5 / 3) - r1 * 5 + 4 - (2 / 3) / r1
    return coeffs


def getTaper(l_domain, obs, model, radius, cutoff):
    if model.dg is None:
        return None

    x = np.concatenate([np.asarray(pyMEB.getVarCoordinate(model.dg, varname) ).T
                        for varname in model.dim if varname in varnames_state], axis=0)*1e-3
    xo = np.concatenate([np.asarray(pyMEB.getVarCoordinate(model.dg, varname) ).T[condition]
                         for varname, condition in obs.igrid.items()], axis=0)*1e-3
    d = xo[:, None] - x[l_domain]
    # average distance from observation to local domain
    dist = np.sqrt((d * d).sum(axis=-1)).mean(-1)
    coeffs = np.concatenate([GC(dist[range(*d)], radius[varname]) for varname, d in obs.dim.items()])
    inds   = np.arange(len(dist))[coeffs > cutoff]
    return inds, np.sqrt(coeffs[inds])